@@ -129,13 +129,13 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     KLocalizedString::setApplicationDomain("pix");
 
     KAboutData about(QStringLiteral("pix"),
-                     i18n("Pix"),
+                     QStringLiteral("Pix"),
                      PIX_VERSION_STRING,
                      i18n("Organize, browse, and edit your images."),
                      KAboutLicense::LGPL_V3,
-                     i18n("© 2019-2023 Maui Development Team"),
+                     APP_COPYRIGHT_NOTICE,
                      QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
-    about.addAuthor(i18n("Camilo Higuita"), i18n("Developer"), QStringLiteral("milo.h@aol.com"));
+    about.addAuthor(QStringLiteral("Camilo Higuita"), i18n("Developer"), QStringLiteral("milo.h@aol.com"));
     about.setHomepage("https://mauikit.org");
     about.setProductName("maui/pix");
     about.setBugAddress("https://invent.kde.org/maui/pix/-/issues");
